@@ -1,4 +1,3 @@
-use std::env;
 use std::io::Write;
 use std::path;
 
@@ -32,11 +31,10 @@ impl ConfigArgs {
         // Fetch config information if available
         let mut config = if let Some(config_path) = config_path {
             cobalt_config::Config::from_file(config_path).with_context(|| {
-                anyhow::format_err!("Error reading config file {:?}", config_path)
+                anyhow::format_err!("Error reading config file {}", config_path.display())
             })?
         } else {
-            let cwd = env::current_dir().unwrap_or_default();
-            cobalt_config::Config::from_cwd(cwd)?
+            cobalt_config::Config::from_cwd(".")?
         };
 
         config.abs_dest = self
