@@ -39,7 +39,11 @@ impl FilesBuilder {
     }
 
     pub fn add_ignore(&mut self, line: &str) -> Result<&mut Self> {
-        trace!("{:?}: adding '{}' ignore pattern", self.root_dir, line);
+        trace!(
+            "{}: adding '{}' ignore pattern",
+            self.root_dir.display(),
+            line
+        );
         self.ignore.push(line.to_owned());
         Ok(self)
     }
@@ -55,7 +59,7 @@ impl FilesBuilder {
     }
 
     pub fn add_extension(&mut self, ext: &str) -> Result<&mut FilesBuilder> {
-        trace!("{:?}: adding '{}' extension", self.root_dir, ext);
+        trace!("{}: adding '{}' extension", self.root_dir.display(), ext);
         self.extensions.push(ext.into());
         Ok(self)
     }
@@ -211,11 +215,11 @@ impl Files {
         match self.ignore.matched(path, is_dir) {
             Match::None => true,
             Match::Ignore(glob) => {
-                trace!("{:?}: ignored {:?}", path, glob.original());
+                trace!("{}: ignored {:?}", path.display(), glob.original());
                 false
             }
             Match::Whitelist(glob) => {
-                trace!("{:?}: allowed {:?}", path, glob.original());
+                trace!("{}: allowed {:?}", path.display(), glob.original());
                 true
             }
         }
